/**
 * Copyright (c) 2009-2011 Zauber S.A. <http://www.zaubersoftware.com/>
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package com.zauberlabs.commons.ws;

import java.util.List;

import javax.xml.ws.BindingProvider;
import javax.xml.ws.handler.Handler;
import javax.xml.ws.handler.soap.SOAPHandler;
import javax.xml.ws.handler.soap.SOAPMessageContext;

/**
 * Utility class for {@link SOAPHandler}s
 * 
 * @author flbulgarelli
 */
public final class SoapHandlers {

    /***/
    private SoapHandlers() {
        // Companion
    }

    /**
     * Registers a {@link SOAPHandler} into a {@link BindingProvider}'s handler
     * chain
     * 
     * @param bindingProvider
     * @param soapHandler
     */
    @SuppressWarnings("unchecked")
    public static void add(final BindingProvider bindingProvider,
            final SOAPHandler<SOAPMessageContext> soapHandler) {
        List<Handler> handlerChain = bindingProvider.getBinding().getHandlerChain();
        handlerChain.add(soapHandler);
        bindingProvider.getBinding().setHandlerChain(handlerChain);
    }

}
