/**
 * Copyright (c) 2009-2011 Zauber S.A. <http://www.zaubersoftware.com/>
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package com.zauberlabs.commons.ws.connection.cxf;


import org.apache.cxf.endpoint.Client;
import org.apache.cxf.transport.http.HTTPConduit;
import org.apache.cxf.transports.http.configuration.HTTPClientPolicy;

import com.zauberlabs.commons.ws.connection.Configuration;

/**
 * Configuration that configures options of the underlying http conduit of a WS
 * connection
 * 
 * @author flbulgarelli
 */
public class HttpConfiguration extends AbstractClientConfiguration {

    private final HTTPClientPolicy httpClientPolicy;

    /**
     * Creates an {@link HttpConfiguration}
     * 
     * @param httpClientPolicy
     */
    public HttpConfiguration(final HTTPClientPolicy httpClientPolicy) {
        this.httpClientPolicy = httpClientPolicy;
    }

    @Override
    protected void configureClient(final Client client) {
        HTTPConduit http = (HTTPConduit) client.getConduit();
        http.setClient(httpClientPolicy);
    }

    /**
     * Answers a {@link Configuration} that configures a {@link Client} using
     * the given {@link HTTPClientPolicy}
     * 
     * @param clientPolicy
     * @return a new {@link HttpConfiguration}
     */
    public static Configuration<Object> from(final HTTPClientPolicy clientPolicy) {
        return new HttpConfiguration(clientPolicy);
    }

}
